type Path<T, Prefix extends ReadonlyArray<unknown> = readonly []> = T extends ReadonlyArray<unknown> ? Path<T[number], readonly [...Prefix, number]> | Prefix : T extends object ? PathsOfObject<T, Prefix> | Prefix : Prefix;
type PathsOfObject<T, Prefix extends ReadonlyArray<unknown>> = {
    [K in keyof T]-?: Path<T[K], readonly [...Prefix, K]>;
}[keyof T];
type ValueAtPath<T, TPath extends Path<T>> = TPath extends readonly [
    infer Head,
    ...infer Rest
] ? Head extends keyof T ? Rest extends Path<T[Head]> ? ValueAtPath<T[Head], Rest> : never : never : T;
/**
 * Sets the value at `path` of `object`.
 *
 * For simple cases where the path is only one level deep, prefer `set` instead.
 *
 * @param data - The target method.
 * @param path - The array of properties.
 * @param value - The value to set.
 * @signature
 *    R.setPath(obj, path, value)
 * @example
 *    R.setPath({ a: { b: 1 } }, ['a', 'b'], 2) // => { a: { b: 2 } }
 * @dataFirst
 * @category Object
 */
declare function setPath<T, TPath extends Path<T>>(data: T, path: TPath, value: ValueAtPath<T, TPath>): T;
/**
 * Sets the value at `path` of `object`.
 *
 * @param path - The array of properties.
 * @param value - The value to set.
 * @signature
 *    R.setPath(path, value)(obj)
 * @example
 *    R.pipe({ a: { b: 1 } }, R.setPath(['a', 'b'], 2)) // { a: { b: 2 } }
 * @dataLast
 * @category Object
 */
declare function setPath<T, TPath extends Path<T>, Value extends ValueAtPath<T, TPath>>(path: TPath, value: Value): (data: T) => T;
declare function setPathImplementation(data: unknown, path: ReadonlyArray<PropertyKey>, value: unknown): unknown;

export { setPath, setPathImplementation };
